Simulation with observer based state feedback of the reaction-convection-diffusion equation
-------------------------------------------------------------------------------------------

.. autoapimodule:: pyinduct.examples.rad_eq_const_coeff
    :members:
    :undoc-members:
    :show-inheritance:

